@@ -5,7 +5,7 @@ from importlib import metadata as importlib_metadata
 
 from pycvcqv.cqv import cqv
 from pycvcqv.cv import coefficient_of_variation
-from pycvcqv.dataframe import processor_cqv, processor_cv
+from pycvcqv.dataframe import cqv_dataframe, cv_dataframe
 from pycvcqv.is_numeric import is_numeric
 
 # -------------------------------- function definition --------------------------------
@@ -25,6 +25,6 @@ __all__ = [
     "coefficient_of_variation",
     "is_numeric",
     "cqv",
-    "processor_cv",
-    "processor_cqv",
+    "cv_dataframe",
+    "cqv_dataframe",
 ]
